==> elasticsearch-java-7.15.0-sources.jar: co/elastic/clients/elasticsearch/ingest/UserAgentProperty.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.ingest;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.util.StringEnum;

@JsonpDeserializable
public enum UserAgentProperty implements StringEnum {
	Name("NAME"), Major("MAJOR"), Minor("MINOR"), Patch("PATCH"), Os("OS"), OsName("OS_NAME"), OsMajor(
			"OS_MAJOR"), OsMinor("OS_MINOR"), Device("DEVICE"), Build("BUILD");

	private final String jsonValue;

	UserAgentProperty(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final StringEnum.Deserializer<UserAgentProperty> _DESERIALIZER = new StringEnum.Deserializer<>(
			UserAgentProperty.values());
}

==> elasticsearch-java-7.16.3-sources.jar: co/elastic/clients/elasticsearch/ingest/UserAgentProperty.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.ingest;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/ingest/_types/Processors.ts#L75-L86">API
 *      specification</a>
 */
@JsonpDeserializable
public enum UserAgentProperty implements JsonEnum {
	Name("NAME"),

	Major("MAJOR"),

	Minor("MINOR"),

	Patch("PATCH"),

	Os("OS"),

	OsName("OS_NAME"),

	OsMajor("OS_MAJOR"),

	OsMinor("OS_MINOR"),

	Device("DEVICE"),

	Build("BUILD"),

	;

	private final String jsonValue;

	UserAgentProperty(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<UserAgentProperty> _DESERIALIZER = new JsonEnum.Deserializer<>(
			UserAgentProperty.values());
}
